aboutsummaryrefslogtreecommitdiff
path: root/gcc/function.c
diff options
context:
space:
mode:
authorRichard Henderson <rth@cygnus.com>1999-01-11 14:37:20 -0800
committerRichard Henderson <rth@gcc.gnu.org>1999-01-11 14:37:20 -0800
commit3b413743e0719ecca26e5f5426b6baa837e0a13b (patch)
tree30a7e0f87a7c337abe0059287db7fcfd192c14ae /gcc/function.c
parentf0974237d4c4f761f5073cfd93583a571651ba76 (diff)
downloadgcc-3b413743e0719ecca26e5f5426b6baa837e0a13b.zip
gcc-3b413743e0719ecca26e5f5426b6baa837e0a13b.tar.gz
gcc-3b413743e0719ecca26e5f5426b6baa837e0a13b.tar.bz2
basic-block.h (basic_block_head): Rename to x_basic_block_head.
* basic-block.h (basic_block_head): Rename to x_basic_block_head. (basic_block_end): Rename to x_basic_block_end. (BLOCK_HEAD, BLOCK_END): Update. * caller-save.c: Change basic_block_head/end references to BLOCK_HEAD/END. * combine.c, flow.c, function.c, gcse.c, global.c: Likewise. * graph.c, haifa-sched.c, local-alloc.c, regclass.c: Likewise. * regmove.c, reload1.c, reorg.c, sched.c: Likewise. From-SVN: r24622
Diffstat (limited to 'gcc/function.c')
-rw-r--r--gcc/function.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/gcc/function.c b/gcc/function.c
index d9575cc..865e679 100644
--- a/gcc/function.c
+++ b/gcc/function.c
@@ -6267,9 +6267,9 @@ thread_prologue_and_epilogue_insns (f)
/* Include the new prologue insns in the first block. Ignore them
if they form a basic block unto themselves. */
- if (basic_block_head && n_basic_blocks
- && GET_CODE (basic_block_head[0]) != CODE_LABEL)
- basic_block_head[0] = NEXT_INSN (f);
+ if (x_basic_block_head && n_basic_blocks
+ && GET_CODE (BLOCK_HEAD (0)) != CODE_LABEL)
+ BLOCK_HEAD (0) = NEXT_INSN (f);
/* Retain a map of the prologue insns. */
prologue = record_insns (GET_CODE (seq) == SEQUENCE ? seq : head);
@@ -6335,9 +6335,9 @@ thread_prologue_and_epilogue_insns (f)
/* Include the new epilogue insns in the last block. Ignore
them if they form a basic block unto themselves. */
- if (basic_block_end && n_basic_blocks
- && GET_CODE (basic_block_end[n_basic_blocks - 1]) != JUMP_INSN)
- basic_block_end[n_basic_blocks - 1] = tail;
+ if (x_basic_block_end && n_basic_blocks
+ && GET_CODE (BLOCK_END (n_basic_blocks - 1)) != JUMP_INSN)
+ BLOCK_END (n_basic_blocks - 1) = tail;
/* Retain a map of the epilogue insns. */
epilogue = record_insns (GET_CODE (seq) == SEQUENCE ? seq : tail);
@@ -6397,10 +6397,10 @@ reposition_prologue_and_epilogue_notes (f)
if (next)
PREV_INSN (next) = prev;
/* Whether or not we can depend on basic_block_head,
attempt to keep it up-to-date. */
- if (basic_block_head[0] == note)
- basic_block_head[0] = next;
+ if (BLOCK_HEAD (0) == note)
+ BLOCK_HEAD (0) = next;
add_insn_after (note, insn);
}
@@ -6441,11 +6441,11 @@ reposition_prologue_and_epilogue_notes (f)
if (next)
PREV_INSN (next) = prev;
/* Whether or not we can depend on basic_block_head,
attempt to keep it up-to-date. */
if (n_basic_blocks
- && basic_block_head[n_basic_blocks-1] == insn)
- basic_block_head[n_basic_blocks-1] = note;
+ && BLOCK_HEAD (n_basic_blocks-1) == insn)
+ BLOCK_HEAD (n_basic_blocks-1) = note;
add_insn_before (note, insn);
}
@@ -6397,10 +6397,10 @@ reposition_prologue_and_epilogue_notes (f)
if (next)
PREV_INSN (next) = prev;
- /* Whether or not we can depend on basic_block_head,
+ /* Whether or not we can depend on BLOCK_HEAD,
attempt to keep it up-to-date. */
@@ -6441,11 +6441,11 @@ reposition_prologue_and_epilogue_notes (f)
if (next)
PREV_INSN (next) = prev;
- /* Whether or not we can depend on basic_block_head,
+ /* Whether or not we can depend on BLOCK_HEAD,
attempt to keep it up-to-date. */
if (n_basic_blocks